Praxis Seizure: Kansas City Kansas City, Missouri June 10th 2000 8 players Stephen Wyatt https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/czrQTcZJhKE/discussion Crypt (13 cards, min=14, max=28, avg=5.23) ------------------------------------------ 1x Anson 8 CEL PRE aus dom prince Toreador:1 1x Eliott Sinclair, Virtuoso Thespian 7 PRE aus cel primogen Toreador:1 1x Tatiana Romanov 7 AUS cel pre prince Toreador:1 1x Adrianne 6 aus cel pot pre Toreador:1 1x Kallista, Master Sculptor 6 AUS CEL pre pro Toreador:1 1x Sigrid Bekker 6 AUS cel pot pre Toreador:2 1x Felicia Mostrom 5 AUS CEL pre Toreador:1 1x Ramiel DuPre 5 PRE aus cel dom Toreador:1 1x Demetrius Slater 4 aus cel pre Toreador:1 1x Dorian Strack 4 AUS cel Toreador:1 1x Mariana Gilbert 4 PRE cel Toreador:1 1x Colin Flynn 3 aus cel Toreador:1 1x Isabel de Leon 3 AUS Toreador:2 Library (90 cards) Master (20) 1x Aching Beauty 1x Art Museum 2x Ascendance 2x Auspex 2x Blood Doll 1x Major Boon 1x Minion Tap 2x Misdirection 4x Presence 1x Short-Term Investment 1x Society Hunting Ground 2x Sudden Reversal Action (22) 8x Enchant Kindred 1x Entrancement 2x Kindred Intelligence 4x Legal Manipulations 2x Media Influence 1x Propaganda 1x Pulse of the Canaille 3x Social Charm Equipment (1) 1x Palatial Estate Retainer (2) 2x Marijava Ghoul Action Modifier (2) 2x Aire of Elation Reaction (28) 1x Eagle's Sight 1x Enhanced Senses 2x Forced Awakening 2x Precognition 2x Spirit's Touch 9x Telepathic Counter 11x Telepathic Misdirection Combat (15) 1x Catatonic Fear 12x Majesty 2x Staredown